package com.nisum.example.controller;

import com.nisum.example.constants.ProductConstants;
import com.nisum.example.mapper.ProductMapper;
import com.nisum.example.model.Product;
import com.nisum.example.service.IProductService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping(value = ProductConstants.PRODUCT_SERVICE_ROOT,produces = MediaType.APPLICATION_JSON_VALUE)
@Slf4j
public class ProductController {

    @Autowired
    private ProductMapper productMapper;

    @Autowired
    private IProductService productService;

    @PostMapping(value = "/product-create",consumes = MediaType.APPLICATION_JSON_VALUE)
    @ResponseStatus(HttpStatus.CREATED)
    public Mono<Product> createProduct(@RequestBody Product product){
        log.info("Calling service saveProduct() ...");
       return productService.saveProduct(productMapper.toDto(product))
               .map(productMapper::toModel)
               .log();
    }

    @GetMapping(value = "/product-get/{id}")
    @ResponseStatus(HttpStatus.OK)
    public Mono<Product> fetchProduct(@PathVariable String id){
        log.info("Calling service getProduct()...");
        return productService.getProduct(id)
                .map(productMapper::toModel)
                .log();

    }
}
