package com.nisum.example.service;

import com.nisum.example.dto.ProductDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.ReactiveMongoTemplate;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

/**
 * Product Service class
 */
@Service
@Slf4j
public class ProductServiceImpl implements IProductService {

    @Autowired
    private ReactiveMongoTemplate reactiveMongoTemplate;

    /**
     *Perform save operation of one product
     * @param productDTO
     * @return Mono<ProductDTO>
     */
    @Override
    public Mono<ProductDTO> saveProduct(ProductDTO productDTO) {
        log.info("Calling template save()...");
        return reactiveMongoTemplate.save(productDTO);
    }

    /**
     * Perform get operation based on id
     * @param id
     * @return Mono<ProductDTO>
     */
    @Override
    public Mono<ProductDTO> getProduct(String id) {
        log.info("Calling service findById()...");
        return reactiveMongoTemplate.findById(id,ProductDTO.class);
    }
}
